#
# spec file for package supermin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           supermin
VCS: https://src.suse.de/SLFO-pool/supermin#cc09c76089b7a2d13477da255d07406e3d838e4d86107fa44d471929a16076c8
Version:        5.3.3
Release:        slfo.1.1_1.1
Summary:        Bootstrapping tool for creating supermin appliances
License:        GPL-3.0-or-later
Group:          System/Filesystems
URL:            https://libguestfs.org/
Source0:        https://download.libguestfs.org/supermin/5.3-development/supermin-5.3.3.tar.gz
Source1:        https://download.libguestfs.org/supermin/5.3-development/supermin-5.3.3.tar.gz.sig
Source9:        supermin.keyring
Patch1:         001-Improved-debugging-of-the-supermin-if-newer-calculation.patch
Patch2:         002-Fix-if-newer-copy-kernel.patch
Patch3:         003-Fix-kernel-filtering-for-aarch64-architecture.patch
Patch4:         004-Use-output-complete-exe-instead-of-custom.patch
Patch5:         005-Only-supply-output-complete-exe-to-final-link.patch
Patch6:         006-Rename-function-file-kernel.patch
Patch7:         007-Uncompress-kernel-on-RISC-V.patch
Patch8:         008-Fix-link-to-renamed-kernel-documentation.patch
Patch9:         009-New-mailing-list-email-address.patch
Patch30:        suse_release.patch
Patch31:        supermin-kernel_version_compressed.patch
Patch32:        disable-test-if-newer-ext2.patch
Patch33:        detect-aarch64-kernel.patch
BuildRequires:  augeas
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  distribution-release
BuildRequires:  e2fsprogs
BuildRequires:  glibc-devel-static
BuildRequires:  gzip
BuildRequires:  hivex
BuildRequires:  kernel-default
BuildRequires:  ncurses-devel
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-rpm-macros >= 4.02.1
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  zstd
BuildRequires:  zypper
BuildRequires:  pkgconfig(com_err)
BuildRequires:  pkgconfig(ext2fs)
BuildRequires:  pkgconfig(rpm)
Requires:       distribution-release
%if 0%{?suse_version} < 1599
Requires:       sysconfig-netconfig
%endif
Requires:       tar
Requires:       xmlstarlet
Requires:       zypper
Provides:       febootstrap
%{?ocaml_preserve_bytecode}
# this must follow libguestfs, which is the only consumer of this pkg
ExclusiveArch:  x86_64 ppc64 ppc64le s390x aarch64 riscv64

%description
supermin is a tool for building supermin appliances. These are tiny
appliances (similar to virtual machines), usually around 100KB in size,
which get fully instantiated on-the-fly in a fraction of a second when
you need to boot one of them.

%prep
%autosetup -p1

%build
export ZYPPER=zypper
export ZYPPER=%{_bindir}/zypper
touch INSTALL NEWS AUTHORS ChangeLog
#.gnulib/gnulib-tool --update
autoreconf -fi
%configure --help
%configure --disable-network-tests
%make_build \
	%{?_smp_mflags}

%install
%make_install
find %{buildroot} -ls

%check
ls -alt /boot /lib/modules || :
ls -altd /lib/modules/*/* || :

for i in /boot/image* /boot/Image* /boot/vmlinu* /boot/zImage*
do
  test -f "$i" || continue
  if get_kernel_version "${i}" > $$
  then
    if test -s $$
    then
      read SUPERMIN_KERNEL_VERSION < $$
      export "SUPERMIN_KERNEL=$i"
      export "SUPERMIN_KERNEL_VERSION=$SUPERMIN_KERNEL_VERSION"
      export "SUPERMIN_MODULES=/lib/modules/${SUPERMIN_KERNEL_VERSION}"
      break
    fi
  fi
done
rm -fv $$
test -n "${SUPERMIN_KERNEL}"
test -n "${SUPERMIN_KERNEL_VERSION}"
test -d "${SUPERMIN_MODULES}"
%ifnarch s390x
if make check
then
  rc=0
else
  : rc $?
  rc=1
fi
cat tests/test-suite.log
exit ${rc}
%endif

%files
%doc README
%doc TODO
%{_bindir}/*
%{_mandir}/*/*

%changelog
* Thu Jan  4 2024 carnold@suse.com
- Update to version 5.3.3 (jsc#PED-6305)
  * initrd: Support ztd-compressed modules
  * pacman: Recognise Artix, an Arch derivative
  * Add a separate variable to store link flags, and use that to
    supply
  * Add appropriate globs for arm based kernels. The file names end
    in -arm64 but the architecture is named aarch64.
  * Add support for OCaml 5.0
  * Add LFS support for fts functions
  * Numerous bug fixes
- Upstream bug fixes and features
  001-Improved-debugging-of-the-supermin-if-newer-calculation.patch
  002-Fix-if-newer-copy-kernel.patch
  003-Fix-kernel-filtering-for-aarch64-architecture.patch
  004-Use-output-complete-exe-instead-of-custom.patch
  005-Only-supply-output-complete-exe-to-final-link.patch
  006-Rename-function-file-kernel.patch
  007-Uncompress-kernel-on-RISC-V.patch
  008-Fix-link-to-renamed-kernel-documentation.patch
  009-New-mailing-list-email-address.patch
- Dropped initrd_support_ztd-compressed_modules.patch
* Tue Dec 27 2022 schwab@suse.de
- Enable build on riscv64
* Fri Dec  9 2022 kukuk@suse.com
- Include sysconfig-netconfig only until SLE15, newer versions
  don't use it anymore [jsc#PED-1734]
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Mon Apr 25 2022 carnold@suse.com
- Update to 5.2.2 bug fix release
  * Open Unix.LargeFile to avoid "lstat: Value too large for
    defined data type"
  * pacman: Skip over detached signatures when unpacking
  * ext2, rpm: Don't redefine Val_none or Some_val.
  * Don't attempt to build man page if perldoc is not available
  * Ignore zfcpdump kernel on s390x
  * Ignore unbootable kernels in /lib/modules
  * Ignore debug kernels
  * maintainer: Add our usual maintainer rules
- Drop
  Avoid-lstat-Value-too-large-for-defined-data-type.patch
* Mon Mar  7 2022 carnold@suse.com
- bsc#1187532 - virt-make-fs hangs forever
  detect-aarch64-kernel.patch
* Tue Dec 21 2021 benoit.monin@gmx.fr
- Add initrd_support_ztd-compressed_modules.patch:
  backport of 4306a131c6cd to add support of zstd compressed kernel
  modules.
* Sun Sep 12 2021 ohering@suse.de
- Restore ExclusiveArch, continue to follow libguestfs
  The 'almost' below is the reason.
* Thu Sep  9 2021 ohering@suse.de
- arm32 may have a kernel named /boot/zImage
* Thu Sep  9 2021 jengelh@inai.de
- Remove arch exclusion, almost all of them build.
* Tue Aug 31 2021 ohering@suse.de
- s390x may have a kernel named /boot/image
* Wed Aug 25 2021 carnold@suse.com
- Update to 5.2.1 bug fix release. Include post 5.2.1 upstream fix.
  Avoid-lstat-Value-too-large-for-defined-data-type.patch
  disable-test-if-newer-ext2.patch
* Thu Apr  1 2021 schwab@suse.de
- Fix typo risc64 -> riscv64
* Fri Feb  5 2021 ro@suse.de
- add patch supermin-kernel_version_compressed.patch
  find kernel module path even for compressed kernels
  like on aarch64 and s390x (bsc#1182112, bsc#1138258)
* Fri Oct 23 2020 dmueller@suse.com
- update to 5.2.0:
  * rpm: extend the Multiple_matches exception
  * Use external command mv to rename old output directory (RHBZ#1670191).
  * rpm: do not unpack parameters
  * rpm: fix version comparison
  * rpm: provide a dummy supermin_rpm_get_arch implementation
  * ext2: Build symbolic links correctly (RHBZ#1770304).
  * Update gnulib to latest.
- switch to release tarball, use keyring for gpg validation
- run tests
* Fri Nov  1 2019 ohering@suse.de
- Update to version 5.1.20, via _service file
  No changelog provided by upstream
* Wed Jul 31 2019 ldewey@suse.com
- Adding sysconfig-netconfig to list of required dependencie
  (BSC#136878)
* Tue May  7 2019 ldewey@suse.com
- Added tar as software dependency.
  (BSC#1134334)
* Thu Aug 31 2017 cbosdonnat@suse.com
- Distro detection: also use ID_LIKE to catch suse distros
  add patch: suse_release.patch
* Thu Jul 13 2017 cbosdonnat@suse.com
- Update to version 5.1.18
* Tue May 30 2017 olaf@aepfle.de
- Update to version 5.1.17
  remove 0001-add_simple_handling_of_os-release.patch
  remove 0002-use_os-release_to_detect_the_distro.patch
  remove 0003-tests_use__etc_os-release_in_test-harder.patch
* Thu Sep  8 2016 cbosdonnat@suse.com
- Remove use of SuSE-release and use os-release instead. (bsc#997936)
  0001-add_simple_handling_of_os-release.patch
  0002-use_os-release_to_detect_the_distro.patch
  0003-tests_use__etc_os-release_in_test-harder.patch
* Thu May 26 2016 cbosdonnat@suse.com
- fate#316274
* Wed May 25 2016 olaf@aepfle.de
- Preserve bytecode
* Fri Oct 23 2015 olaf@aepfle.de
- Update to version 5.1.13
* Mon Oct 20 2014 ohering@suse.com
- Update to version 5.1.10
* Tue May 13 2014 ohering@suse.de
- Update to version 5.1.8
* Mon Aug 19 2013 ohering@suse.de
- Update to version 4.1.3
* Tue Jun  4 2013 ohering@suse.de
- zypp: Only compile zypper support if OCaml inifiles module is found.
- zypp: Trailing whitespace.
- Handle --packager-config in zypp_rpm
- helper: Add a note that cpio might not be able to read -f cpio files.
- helper: Add megaraid drivers to the initrd.
* Tue Apr  9 2013 ohering@suse.de
- add changes to support zypper
* Sat Mar  9 2013 ohering@suse.de
- initial package version 4.1.1
